% make Post 6 figures
% for copyright notice see accompanying license.txt
% REA 2011-06-14->20

%% load projections 
dirname = 'E:\Projects\Blog\Posts\P6CTrecon'; % edit this for your computer
if dirname(end) ~= filesep
   dirname(end+1) = filesep;
end
load([dirname 'P6prj.mat']); % loads prj = object projections

%% reconstruct with iradon
[nlines,nangles] = size(prj);
angles = linspace(0,180,nangles+1); % 0 to 180 degrees
[img2,Hiradon] = iradon(prj,angles(1:(end-1)),'cosine',0.9); 

%% plot data
fh = figure;
plot(img2(end/2,:),'-k','linewidth',1.5)   
axis([0 350 -0.2 1.2])
hold on
plot([0 350],[1 1],':r','linewidth',1.5)
plot([0 350],[0 0],':r','linewidth',1.5)
hold off
set(gca,'fontsize',12,'linewidth',1.5)

%% export the plots
figno = sprintf('-f%d',fh);
print(figno,[dirname 'iradon_dat.png'],'-dpng','-cmyk','-r100') % resolution 100 dpi
   % export as eps
print(figno,[dirname 'iradon_dat.eps'],'-deps','-cmyk') 

%% reconstruct with CTrecon
[img,Hctrecon] = CTrecon(prj,'filter_type','cosine','freq_cutoff',0.9); 

%% display projections and reconstructed image
fh = figure;
subplot(121)
imshow(prj,[]);
subplot(122)
imshow(img, [])
set(fh,'color','w','position',[250 1000 650 350]);

%% export the image as png and eps
figno = sprintf('-f%d',fh);
print(figno,[dirname 'prj_img.png'],'-dpng','-cmyk','-r75') % resolution 75 dpi
   % export as eps
print(figno,[dirname 'prj_img.eps'],'-deps','-cmyk') 

%% plot data
fh = figure;
plot(img(end/2,:),'-k','linewidth',1.5)   
axis([0 350 -0.2 1.2])
hold on
plot([0 350],[1 1],':r','linewidth',1.5)
plot([0 350],[0 0],':r','linewidth',1.5)
hold off
set(gca,'fontsize',12,'linewidth',1.5)

%% export the plots
figno = sprintf('-f%d',fh);
print(figno,[dirname 'CTrecon_dat.png'],'-dpng','-cmyk','-r100') % resolution 100 dpi
   % export as eps
print(figno,[dirname 'CTrecon_dat.eps'],'-deps','-cmyk') 

%% plot the transfer functions
   % normalize the transfer functions: 
Hiradon = Hiradon/max(Hiradon);
Hctrecon = Hctrecon/max(Hctrecon);
fh = figure;
linewid = 1.5;
hold on
plot(0:(numel(Hctrecon)-1),Hctrecon,'--r','linewidth',linewid);
plot(0:(numel(Hctrecon)-1),Hiradon,'-k','linewidth',linewid);
hold off
axis([0 2 0 0.01])
hl = legend('Hctrecon','Hiradon','location','southeast');
xlabel('frequency','fontsize',12);
ylabel('H','fontsize',12);
set(gca,'XtickLabel',{});
set(gca,'fontsize',12,'linewidth',1.5)
set(fh,'color','w','position',[250 1000 450 350]);

%% export the transfer functionplot
figno = sprintf('-f%d',fh);
fname = 'TransferFunction';
print(figno,[dirname fname '.png'],'-dpng','-cmyk','-r75') % resolution in dpi
   % export as eps
print(figno,[dirname fname '.eps'],'-deps','-cmyk') 


